@@ -2,5 +2,7 @@ __author__ = 'gsibble'
 
 from amount import CoinbaseAmount
 from transaction import CoinbaseTransaction
+from transfer import CoinbaseTransfer
 from contact import CoinbaseContact
-from user import CoinbaseUser
\ No newline at end of file
+from user import CoinbaseUser
+from error import CoinbaseError
\ No newline at end of file
