@@ -1,10 +1,10 @@
 __author__ = 'gsibble'
 
-class CoinBaseAmount(float):
+class CoinbaseAmount(float):
 
     def __new__(self, amount, currency):
         return float.__new__(self, amount)
 
     def __init__(self, amount, currency):
-        super(CoinBaseAmount, self).__init__()
+        super(CoinbaseAmount, self).__init__()
         self.currency = currency
